@@ -28,9 +28,8 @@ func main() {
 	// Retrieve args and Shift binary name off argument list.
 	args := os.Args[1:]
 
-	err := cli.Run(args, os.Stdout)
-	if err != nil {
-		fmt.Printf("Error: %s\n", err)
+	if err := cli.Run(args, os.Stdout, os.Stderr, os.Stdin); err != nil {
+		fmt.Fprintf(os.Stderr, "Error: %s.\n", err)
 		os.Exit(1)
 	}
 }
