@@ -48,8 +48,7 @@ func NewPasswordStore(storePath string) *PasswordStore {
 
 	// Find the GPG bin
 	which := exec.Command("which", "gpg2")
-	err := which.Run()
-	if err == nil {
+	if err := which.Run(); err == nil {
 		s.GPGBin = "gpg2"
 	} else {
 		s.GPGBin = "gpg"
@@ -71,15 +70,14 @@ func (store *PasswordStore) Init(gpgID string) error {
 		//Path exists, but is it a directory?
 		if fi.Mode().IsDir() == false {
 			return fmt.Errorf(
-				"Could not create password store. Path `%s` already exists and it is not a directory.",
+				"could not create password store. Path \"%s\" already exists and it is not a directory",
 				store.Path)
 		}
 	} else {
 		//Error during os.Stat
 		if os.IsNotExist(err) {
 			//Path does not exist, create it
-			err = os.Mkdir(store.Path, 0700)
-			if err != nil {
+			if err := os.Mkdir(store.Path, 0700); err != nil {
 				return err
 			}
 		} else {
@@ -92,7 +90,7 @@ func (store *PasswordStore) Init(gpgID string) error {
 	fi, err = os.Stat(gpgIDFilePath)
 	if err == nil {
 		//.gpg-id already exists
-		return fmt.Errorf("There is already a .gpg-id file at %s. Stopping init.", gpgIDFilePath)
+		return fmt.Errorf("there is already a .gpg-id file at \"%s\". Stopping init", gpgIDFilePath)
 	}
 
 	gpgIDFile, err := os.Create(path.Join(store.Path, ".gpg-id"))
@@ -103,17 +101,11 @@ func (store *PasswordStore) Init(gpgID string) error {
 	gpgIDFile.WriteString(gpgID + "\n")
 	store.GPGID = gpgID
 
-	err = store.git("init")
-	if err != nil {
+	if err := store.git("init"); err != nil {
 		return err
 	}
 
-	err = store.AddAndCommit("Initial commit", ".gpg-id")
-	if err != nil {
-		return err
-	}
-
-	return nil
+	return store.AddAndCommit("initial commit", ".gpg-id")
 }
 
 //InsertPassword inserts a new password or overwrites an existing one
@@ -123,9 +115,9 @@ func (store *PasswordStore) InsertPassword(pwname, pwtext string) error {
 	//Check if password already exists
 	var gitAction string
 	if containsPassword {
-		gitAction = "Edited"
+		gitAction = "edited"
 	} else {
-		gitAction = "Added"
+		gitAction = "added"
 	}
 
 	gpg := exec.Command(
@@ -144,11 +136,11 @@ func (store *PasswordStore) InsertPassword(pwname, pwtext string) error {
 	output, err := gpg.CombinedOutput()
 
 	if err != nil {
-		return fmt.Errorf("Error: %s" + string(output))
+		return fmt.Errorf("gpg error: \"%s\"", string(output))
 	}
 
 	store.AddAndCommit(
-		fmt.Sprintf("%s password '%s'", gitAction, pwname),
+		fmt.Sprintf("%s password \"%s\"", gitAction, pwname),
 		passwordPath)
 
 	return nil
@@ -159,16 +151,15 @@ func (store *PasswordStore) RemoveDirectory(dirname string) error {
 	containsDirectory, directoryPath := store.ContainsDirectory(dirname)
 
 	if !containsDirectory {
-		return fmt.Errorf("Could not find directory at path %s", directoryPath)
+		return fmt.Errorf("could not find directory at path \"%s\"", directoryPath)
 	}
 
-	err := os.RemoveAll(directoryPath)
-	if err != nil {
+	if err := os.RemoveAll(directoryPath); err != nil {
 		return err
 	}
 
 	store.AddAndCommit(
-		fmt.Sprintf("Removed directory '%s' from the store", dirname),
+		fmt.Sprintf("removed directory \"%s\" from the store", dirname),
 		directoryPath)
 
 	return nil
@@ -179,13 +170,13 @@ func (store *PasswordStore) RemovePassword(pwname string) error {
 	containsPassword, passwordPath := store.ContainsPassword(pwname)
 
 	if !containsPassword {
-		return fmt.Errorf("Could not find password at path %s", passwordPath)
+		return fmt.Errorf("could not find password at path \"%s\"", passwordPath)
 	}
 
 	os.Remove(passwordPath)
 
 	store.AddAndCommit(
-		fmt.Sprintf("Removed password '%s' from the store", pwname),
+		fmt.Sprintf("removed password \"%s\" from the store", pwname),
 		passwordPath)
 
 	return nil
@@ -195,18 +186,17 @@ func (store *PasswordStore) RemovePassword(pwname string) error {
 func (store *PasswordStore) MoveDirectory(source, dest string) error {
 	containsDirectory, sourceDirectoryPath := store.ContainsDirectory(source)
 	if !containsDirectory {
-		return fmt.Errorf("Could not find directory at path %s", sourceDirectoryPath)
+		return fmt.Errorf("could not find directory at path \"%s\"", sourceDirectoryPath)
 	}
 
 	destDirectoryPath := path.Join(store.Path, dest)
 
-	err := os.Rename(sourceDirectoryPath, destDirectoryPath)
-	if err != nil {
+	if err := os.Rename(sourceDirectoryPath, destDirectoryPath); err != nil {
 		return err
 	}
 
 	store.AddAndCommit(
-		fmt.Sprintf("Moved directory '%s' to '%s'", source, dest),
+		fmt.Sprintf("moved directory \"%s\" to \"%s\"", source, dest),
 		sourceDirectoryPath,
 		destDirectoryPath)
 
@@ -218,7 +208,7 @@ func (store *PasswordStore) MovePassword(source, dest string) error {
 	containsPassword, sourcePasswordPath := store.ContainsPassword(source)
 
 	if !containsPassword {
-		return fmt.Errorf("Could not find password path %s", sourcePasswordPath)
+		return fmt.Errorf("could not find password path \"%s\"", sourcePasswordPath)
 	}
 
 	// If the dest ends with a '/', then it is a directory.
@@ -230,13 +220,12 @@ func (store *PasswordStore) MovePassword(source, dest string) error {
 		destPasswordPath = path.Join(store.Path, dest+".gpg")
 	}
 
-	err := os.Rename(sourcePasswordPath, destPasswordPath)
-	if err != nil {
+	if err := os.Rename(sourcePasswordPath, destPasswordPath); err != nil {
 		return err
 	}
 
 	store.AddAndCommit(
-		fmt.Sprintf("Moved Password '%s' to '%s'", source, dest),
+		fmt.Sprintf("moved Password \"%s\" to \"%s\"", source, dest),
 		sourcePasswordPath,
 		destPasswordPath)
 
@@ -248,7 +237,7 @@ func (store *PasswordStore) CopyPassword(source, dest string) error {
 	containsPassword, sourcePasswordPath := store.ContainsPassword(source)
 
 	if !containsPassword {
-		return fmt.Errorf("Could not find password or at path %s", sourcePasswordPath)
+		return fmt.Errorf("could not find password or at path \"%s\"", sourcePasswordPath)
 	}
 
 	// If the dest ends with a '/', then it is a directory.
@@ -260,13 +249,12 @@ func (store *PasswordStore) CopyPassword(source, dest string) error {
 		destPasswordPath = path.Join(store.Path, dest+".gpg")
 	}
 
-	err := gopassio.CopyFileContents(sourcePasswordPath, destPasswordPath)
-	if err != nil {
+	if err := gopassio.CopyFileContents(sourcePasswordPath, destPasswordPath); err != nil {
 		return err
 	}
 
 	store.AddAndCommit(
-		fmt.Sprintf("Copied Password '%s' to '%s'", source, dest),
+		fmt.Sprintf("copied Password \"%s\" to \"%s\"", source, dest),
 		destPasswordPath)
 
 	return nil
@@ -277,17 +265,16 @@ func (store *PasswordStore) CopyDirectory(source, dest string) error {
 	containsDirectory, sourceDirectoryPath := store.ContainsDirectory(source)
 
 	if !containsDirectory {
-		return fmt.Errorf("Could not find directory at path %s", path.Join(store.Path, source))
+		return fmt.Errorf("could not find directory at path \"%s\"", path.Join(store.Path, source))
 	}
 
 	destDirectoryPath := path.Join(store.Path, dest)
-	err := exec.Command("cp", "-r", sourceDirectoryPath, destDirectoryPath).Run()
-	if err != nil {
+	if err := exec.Command("cp", "-r", sourceDirectoryPath, destDirectoryPath).Run(); err != nil {
 		return err
 	}
 
 	store.AddAndCommit(
-		fmt.Sprintf("Copied directory '%s' to '%s'", source, dest),
+		fmt.Sprintf("copied directory \"%s\" to \"%s\"", source, dest),
 		destDirectoryPath)
 
 	return nil
@@ -299,7 +286,7 @@ func (store *PasswordStore) GetPassword(pwname string) (string, error) {
 
 	//Error if the password does not exist
 	if containsPassword == false {
-		return "", fmt.Errorf("Could not find password '%s' at path '%s'", pwname, passwordPath)
+		return "", fmt.Errorf("could not find password \"%s\" at path \"%s\"", pwname, passwordPath)
 	}
 
 	//TODO: Use GPG lib instead
@@ -387,11 +374,9 @@ func (store *PasswordStore) git(args ...string) error {
 	git.Stderr = os.Stderr
 	git.Stdin = os.Stdin
 
-	err := git.Run()
-
-	if err != nil {
+	if err := git.Run(); err != nil {
 		fmt.Println(err.Error())
-		return fmt.Errorf("Git error: %s", err.Error())
+		return fmt.Errorf("git error: \"%s\"", err.Error())
 	}
 
 	return nil
